@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import importlib
 
 import click
@@ -20,8 +21,11 @@ For usage and help on a specific command, run it with a --help flag, e.g.:
     shub schedule --help
 """
 
+CONTEXT_SETTINGS = {'help_option_names': ['-h', '--help']}
 
-@click.group(help=HELP, short_help=SHORT_HELP, epilog=EPILOG)
+
+@click.group(help=HELP, short_help=SHORT_HELP, epilog=EPILOG,
+             context_settings=CONTEXT_SETTINGS)
 @click.version_option(shub.__version__)
 def cli():
     update_url = update_available()
@@ -29,7 +33,9 @@ def cli():
         click.echo("INFO: A newer version of shub is available. Update "
                    "via pip or get it at {}".format(update_url),  err=True)
 
+
 commands = [
+    "bootstrap",
     "deploy",
     "login",
     "deploy_egg",
@@ -41,7 +47,10 @@ commands = [
     "schedule",
     "log",
     "requests",
-    "copy_eggs"
+    "copy_eggs",
+    "migrate_eggs",
+    "image",
+    "cancel",
 ]
 
 for command in commands:
